summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/kateplugin2/plugin_app.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/kateplugin2/plugin_app.cpp')
-rw-r--r--languages/cpp/app_templates/kateplugin2/plugin_app.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/languages/cpp/app_templates/kateplugin2/plugin_app.cpp b/languages/cpp/app_templates/kateplugin2/plugin_app.cpp
index 99d78eff..18595d10 100644
--- a/languages/cpp/app_templates/kateplugin2/plugin_app.cpp
+++ b/languages/cpp/app_templates/kateplugin2/plugin_app.cpp
@@ -7,8 +7,8 @@
#include <kstandarddirs.h>
#include <kfiledialog.h>
-#include <qlayout.h>
-#include <qlabel.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
class PluginView : public KXMLGUIClient
{
@@ -37,14 +37,14 @@ KatePluginFactory::~KatePluginFactory()
delete s_instance;
}
-QObject* KatePluginFactory::createObject( QObject* parent, const char* name, const char*, const QStringList & )
+TQObject* KatePluginFactory::createObject( TQObject* parent, const char* name, const char*, const TQStringList & )
{
return new KatePlugin%{APPNAME}( parent, name );
}
KInstance* KatePluginFactory::s_instance = 0L;
-KatePlugin%{APPNAME}::KatePlugin%{APPNAME}( QObject* parent, const char* name )
+KatePlugin%{APPNAME}::KatePlugin%{APPNAME}( TQObject* parent, const char* name )
: Kate::Plugin ( (Kate::Application*)parent, name )
{
}
@@ -59,7 +59,7 @@ void KatePlugin%{APPNAME}::addView(Kate::MainWindow *win)
PluginView *view = new PluginView ();
(void) new KAction ( i18n("Insert Hello World"), 0, this,
- SLOT( slotInsertHello() ), view->actionCollection(),
+ TQT_SLOT( slotInsertHello() ), view->actionCollection(),
"edit_insert_%{APPNAMELC}" );
view->setInstance (new KInstance("kate"));
@@ -90,11 +90,11 @@ void KatePlugin%{APPNAME}::slotInsertHello()
kv->insertText ("Hello World");
}
-Kate::PluginConfigPage* KatePlugin%{APPNAME}::configPage (uint, QWidget *w, const char* name)
+Kate::PluginConfigPage* KatePlugin%{APPNAME}::configPage (uint, TQWidget *w, const char* name)
{
%{APPNAME}ConfigPage* p = new %{APPNAME}ConfigPage(this, w);
initConfigPage( p );
- connect( p, SIGNAL(configPageApplyRequest(%{APPNAME}ConfigPage*)), this, SLOT(slotApplyConfig(%{APPNAME}ConfigPage*)) );
+ connect( p, TQT_SIGNAL(configPageApplyRequest(%{APPNAME}ConfigPage*)), this, TQT_SLOT(slotApplyConfig(%{APPNAME}ConfigPage*)) );
return (Kate::PluginConfigPage*)p;
}
@@ -114,17 +114,17 @@ void KatePlugin%{APPNAME}::slotApplyConfig( %{APPNAME}ConfigPage* p )
/**
* %{APPNAME}ConfigPage
*/
-%{APPNAME}ConfigPage::%{APPNAME}ConfigPage (QObject* parent /*= 0L*/, QWidget *parentWidget /*= 0L*/)
+%{APPNAME}ConfigPage::%{APPNAME}ConfigPage (TQObject* parent /*= 0L*/, TQWidget *parentWidget /*= 0L*/)
: Kate::PluginConfigPage( parentWidget )
{
- QVBoxLayout* lo = new QVBoxLayout( this, 0, 0, "config_page_layout" );
+ TQVBoxLayout* lo = new TQVBoxLayout( this, 0, 0, "config_page_layout" );
lo->setSpacing(KDialogBase::spacingHint());
- QLabel* lab = new QLabel("KatePlugin%{APPNAME}'s config page", this);
+ TQLabel* lab = new TQLabel("KatePlugin%{APPNAME}'s config page", this);
lo->addWidget(lab);
// TODO: add connection to emit SLOT( changed() )
}
%{APPNAME}ConfigPage::~%{APPNAME}ConfigPage()
@@ -114,17 +114,17 @@ void KatePlugin%{APPNAME}::slotApplyConfig( %{APPNAME}ConfigPage* p )
lo->addWidget(lab);
- // TODO: add connection to emit SLOT( changed() )
+ // TODO: add connection to emit TQT_SLOT( changed() )
}
%{APPNAME}ConfigPage::~%{APPNAME}ConfigPage()